.. :changelog:

History
-------

0.1.2 (2015-07-04)
++++++++++++++++++
* Renaming 'type' field to 'category'

0.1.1 (2015-05-28)
++++++++++++++++++
* First REAL release on PyPI :-)

0.1.0 (2015-05-27)
++++++++++++++++++
* First release on PyPI.
* Basic Sponsor model
* First version of templatetag
* Some tests on model, view and templatetag
* Optional default logo's width and height in settings
* Basic styles
* Admin customized
* Includes a ListView of Sponsors
